@@ -218,43 +218,43 @@ class SQLExecute(object):
                 for row in rowset:
                     m_row = []
                     for column in row:
-                        if str(type(column)).find('java.lang.Object[]') != -1:
+                        if str(type(column)).upper().find('OBJECT[]') != -1:
                             m_ColumnValue = "STRUCTURE("
                             for m_nPos in range(0, len(column)):
                                 m_ColumnType = str(type(column[m_nPos]))
                                 if m_nPos == 0:
-                                    if m_ColumnType.find('str') != -1:
+                                    if m_ColumnType.upper().find('STR') != -1:
                                         m_ColumnValue = m_ColumnValue + "'" + str(column[m_nPos]) + "'"
-                                    elif m_ColumnType.find('JDBCSqlDate') != -1:
+                                    elif m_ColumnType.upper().find('SQLDATE') != -1:
                                         m_ColumnValue = m_ColumnValue + "DATE'" + str(column[m_nPos]) + "'"
-                                    elif str(type(column)).find("Float") != -1:
+                                    elif str(type(column)).upper().find("FLOAT") != -1:
                                         m_ColumnValue = m_ColumnValue + self.options["FLOAT_FORMAT"] % column[m_nPos]
-                                    elif str(type(column)).find("Double") != -1:
+                                    elif str(type(column)).upper().find("DOUBLE") != -1:
                                         m_ColumnValue = m_ColumnValue + self.options["DOUBLE_FORMAT"] % column[m_nPos]
                                     else:
                                         m_ColumnValue = m_ColumnValue + str(column[m_nPos])
                                 else:
-                                    if m_ColumnType.find('str') != -1:
+                                    if m_ColumnType.upper().find('STR') != -1:
                                         m_ColumnValue = m_ColumnValue + ",'" + str(column[m_nPos]) + "'"
-                                    elif m_ColumnType.find('JDBCSqlDate') != -1:
+                                    elif m_ColumnType.upper().find('SQLDATE') != -1:
                                         m_ColumnValue = m_ColumnValue + ",DATE'" + str(column[m_nPos]) + "'"
-                                    elif str(type(column)).find("Float") != -1:
+                                    elif str(type(column)).upper().find("FLOAT") != -1:
                                         m_ColumnValue = m_ColumnValue + "," + \
                                                         self.options["FLOAT_FORMAT"] % column[m_nPos]
-                                    elif str(type(column)).find("Double") != -1:
+                                    elif str(type(column)).upper().find("DOUBLE") != -1:
                                         m_ColumnValue = m_ColumnValue + "," + \
                                                         self.options["DOUBLE_FORMAT"] % column[m_nPos]
                                     else:
                                         m_ColumnValue = m_ColumnValue + "," + str(column[m_nPos])
                             m_ColumnValue = m_ColumnValue + ")"
                             m_row.append(m_ColumnValue)
-                        elif str(type(column)).find('JDBCClobClient') != -1:
+                        elif str(type(column)).upper().find('JDBCCLOBCLIENT') != -1:
                             m_Length = column.length()
                             m_ColumnValue = column.getSubString(1, int(self.options["LOB_LENGTH"]))
                             if m_Length > int(self.options["LOB_LENGTH"]):
                                 m_ColumnValue = m_ColumnValue + "..."
                             m_row.append(m_ColumnValue)
-                        elif str(type(column)).find('JDBCBlobClient') != -1:
+                        elif str(type(column)).upper().find('JDBCBLOBCLIENT') != -1:
                             # 对于二进制数据，用16进制数来显示
                             # 2: 意思是去掉Hex前面的0x字样
                             m_Length = column.length()
@@ -263,11 +263,11 @@ class SQLExecute(object):
                             if m_Length > int(self.options["LOB_LENGTH"]):
                                 m_ColumnValue = m_ColumnValue + "..."
                             m_row.append(m_ColumnValue)
-                        elif str(type(column)).find("Float") != -1:
+                        elif str(type(column)).upper().find("FLOAT") != -1:
                             m_row.append(self.options["FLOAT_FORMAT"] % column)
-                        elif str(type(column)).find("Double") != -1:
+                        elif str(type(column)).upper().find("DOUBLE") != -1:
                             m_row.append(self.options["DOUBLE_FORMAT"] % column)
-                        elif str(type(column)).find('str') != -1:
+                        elif str(type(column)).upper().find('STR') != -1:
                             # 对于二进制数据，其末尾用0x00表示，这里进行截断
                             m_0x00Start = column.find(chr(0))
                             if m_0x00Start != -1:
